package ssw.annotation;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.plugin.*;
import org.osgi.framework.BundleContext;
import ssw.annotation.Preferences.AnnoPreferencePage;
import java.util.*;

/*
 * Created on 14.02.2005
 */

/**
 *   Copyright (C) 2005  Stefan Loidl
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *   
 *   eMail: stefanloidl@gmx.net
 *   
 *   
 * This class is the main plug-in class of the project. It is instantiated once when the plug-in is 
 * started. This single instance can be queried using the static methods of the class. It can be 
 * used to obtain the resources of the plug-in. The resource bundle can be queried and it is possible 
 * to get single strings from the resource bundle. The resources are internationalized. 
 * Moreover images and ImageDescriptors can be received using instance methods. Images within Eclipse 
 * can be supported using the native image registry, which is not done in this case. It is important 
 * to know, that a requested image is always created from a file which may get time consuming if this 
 * fact is not considered. The images can only be referenced by integer values. Integer constants are 
 * defined which may help to choose a valid image. 
 * As usual the preferences of the plug-in can be loaded using the class interface. The default values 
 * of the preferences are actualized on plug-in activation.
 * 
 * @version 1.0.0
 * @author Loidl Stefan, 0255886
 */


public class AnnotationPlugin extends AbstractUIPlugin {
	
	//Constants for getImage
	public static final int IMG_REVIEWED=0;
	public static final int IMG_NOTREVIEWED=1;
	public static final int IMG_NOTREVIEWEDPLUS=2;
	public static final int IMG_EDIT=3;
	public static final int IMG_DEL=4;
	public static final int IMG_ANNO=5;
	public static final int IMG_SHOW=6;
	
	private String[] imageNames={"icons/reviewed.gif","icons/notreviewed.gif",
			"icons/notreviewedplus.gif", "icons/edit.gif","icons/delete.gif",
			"icons/annotation.gif", "icons/showSource.gif"};
	
	//ID refering the Plugin 
	public final static String PluginID="ssw.annotation.Annotations";
	
	//Path to the language resouces
	public final static String ResourceID="ssw.annotation.AnnotationResources.Annotation";

	//The shared instance.
	private static AnnotationPlugin plugin;


	//Resource bundle.
	private ResourceBundle resourceBundle;
	
	/**
	 * Constructor.
	 */
	public AnnotationPlugin() {
		super();
		plugin = this;
		
		try {
			resourceBundle = ResourceBundle.getBundle(ResourceID);
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		//Set default values of preferences
		AnnoPreferencePage.setDefaults(this.getPreferenceStore());
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static AnnotationPlugin getDefault() {
		return plugin;
	}

	/**
	 * Returns the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = AnnotationPlugin.getDefault().getResourceBundle();
		try {
			return (bundle != null) ? bundle.getString(key) : key;
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * Returns an image depending on the the index given.
	 * It does not use the Imageregistry, and is meant 
	 * to be used only for initialisation of objects. 
	 * @param index
	 * @return
	 */
	public Image getImage(int index){
		ImageDescriptor i=getImageDescriptor(index);
		if(i==null) return null;
		return i.createImage();
	}
	
	/**
	 * Returns ImageDescriptor of the specified image.
	 * @param index
	 * @return
	 */
	public ImageDescriptor getImageDescriptor(int index){
		if(index < imageNames.length) 
			return AnnotationPlugin.imageDescriptorFromPlugin(PluginID,imageNames[index]);
		return null;
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle;
	}

}
