
package ssw.annotation.annoview;


import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Image;


import ssw.annotation.AnnotationPlugin;
import ssw.annotation.AnnotationFileHandler.AnnoObject;

/*
 * Created on 14.02.2005
 */
/**
 *   Copyright (C) 2005  Stefan Loidl
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *   
 *   eMail: stefanloidl@gmx.net
 *   
 * This is the label provider for the table used within the Annotation View. 
 * It provides: reviewed (checked), description, points and file. The checked 
 * status is not returned directly, but in the first column a column image is 
 * used to express the state. The images are loaded using the plug-ins main 
 * class interface for images, it is important to know that images queried 
 * from the main plug-in class do not use the native image registry, but are 
 * read from a file each time the query appears. There are three states the 
 * system differs between. 
 * 
 * not reviewed: The annotation contains a negative point modification and 
 * was not marked as review before.  
 * not reviewed plus: The annotation contains a positive point modification 
 * and was not marked as reviewed before.
 * reviewed: independent from the point modification this state is forced if 
 * the annotation was marked as reviewed before.
 * 
 * As the table would not be able to view multi- line descriptions in a correct way, 
 * line separators are replaced with blanks. If an invalid column number is chosen 
 * the provider returns a default string. 
 * 
 * @version 1.0.0
 * @author Loidl Stefan, 0255886
 */
public class AnnoViewLabelProvider extends LabelProvider implements ITableLabelProvider {
	
	private static final String BLANK=" ";
	private String DEFAULT;
	private String LINESEP=System.getProperty("line.separator");
	
	private Image notReviewed;
	private Image notReviewedPlus;
	private Image reviewed;
	
	/**
	 * Constructor
	 */
	public AnnoViewLabelProvider(){
		super();
		reviewed=AnnotationPlugin.getDefault().getImage(AnnotationPlugin.IMG_REVIEWED);
		notReviewed=AnnotationPlugin.getDefault().getImage(AnnotationPlugin.IMG_NOTREVIEWED);
		notReviewedPlus=AnnotationPlugin.getDefault().getImage(AnnotationPlugin.IMG_NOTREVIEWEDPLUS);
		DEFAULT=AnnotationPlugin.getResourceString("AV_LP_DEFAULT");
		
	}
	
	/**
	 * Returns the label shown in the tabel.
	 */
	public String getColumnText(Object obj, int index) {
		switch(index){
			case 0: return BLANK;			//only the Image is shown
			case 1: 
				String desc=((AnnoObject)obj).getDescription().substring(0);
				desc=desc.replaceAll(LINESEP,BLANK);
				return desc;
			case 2: return String.valueOf(((AnnoObject)obj).getPoints());
			case 3: return ((AnnoObject)obj).getFile();
			default: return DEFAULT;
		}
	}
	
	/**
	 * Returns the image shown at the beginning of each field
	 */
	public Image getColumnImage(Object obj, int index) {
		if(index!=0) return null;
		AnnoObject annobj=(AnnoObject)obj;
		return getImage(annobj.isChecked(),annobj.getPoints());
	}
	
	/**
	 * Returns one of the three images.
	 * (notreviewedplus|notreviewed|reviewed)
	 * @param checked
	 * @param points
	 * @return
	 */
	public Image getImage(boolean checked, int points) {
	
		if(checked)return reviewed;
		else {
			if(points>0) return notReviewedPlus;
			return notReviewed;
		}
	}	
	
	
}
